==> weechat_notifier-0.1.41.tar.gz: weechat_notifier-0.1.41/test/test.py <==
#!/usr/bin/env python
import pdb
import irc_message_processor as imp 
import time

imp.init( { "username": "fenton", "monitor_time": 5 } )
start_time = time.time()

incoming_message = { "from_who": "fenton",
                     "channel" : "lisp",
                     "message" : "john clean up your mess!",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
# pdb.set_trace()
imp.printall(incoming_message, response_actions)
imp.perform_actions(response_actions)

imp.pring_sep(2)

incoming_message = { "from_who": "john",
                     "channel" : "lisp",
                     "message" : "this is barrys mess!",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions)
imp.perform_actions(response_actions)

imp.pring_sep(4)

incoming_message = { "from_who": "barry",
                     "channel" : "lisp",
                     "message" : "Let me look",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions)
imp.perform_actions(response_actions)

imp.pring_sep(2)

incoming_message = { "from_who": "barry",
                     "channel" : "lisp",
                     "message" : "Fenton this is really your mess!",
                     "to_me"   : True }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions)
imp.perform_actions(response_actions)

imp.pring_sep(2)

incoming_message = { "from_who": "fenton",
                     "channel" : "lisp",
                     "message" : "Ok I'll clean it up",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions)
imp.perform_actions(response_actions)

==> weechat_notifier-0.1.44.tar.gz: weechat_notifier-0.1.44/test/test.py <==
#!/usr/bin/env python
import pdb
import weechat_notifier.irc_message_processor as imp 
import time


# I write a question on channel #lisp
imp.init( { "username": "fenton", "monitor_time": 5 } )
start_time = time.time()

incoming_message = { "from_who": "fenton",
                     "channel" : "lisp",
                     "message" : "john clean up your mess!",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
# pdb.set_trace()
imp.printall(incoming_message, response_actions,start_time)
imp.perform_actions(response_actions)

# Wait 2 seconds
imp.print_sep(sleep_seconds = 2)

incoming_message = { "from_who": "john",
                     "channel" : "lisp",
                     "message" : "this is barrys mess!",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions,start_time)
imp.perform_actions(response_actions)

imp.print_sep(sleep_seconds = 4)

incoming_message = { "from_who": "barry",
                     "channel" : "lisp",
                     "message" : "Let me look",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions,start_time)
imp.perform_actions(response_actions)

imp.print_sep(sleep_seconds = 2)

incoming_message = { "from_who": "barry",
                     "channel" : "lisp",
                     "message" : "Fenton this is really your mess!",
                     "to_me"   : True }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions,start_time)
imp.perform_actions(response_actions)

imp.print_sep(sleep_seconds = 2)

incoming_message = { "from_who": "fenton",
                     "channel" : "lisp",
                     "message" : "Ok I'll clean it up",
                     "to_me"   : False }
response_actions = imp.generate_actions_from_irc_message(incoming_message)
imp.printall(incoming_message, response_actions,start_time)
imp.perform_actions(response_actions)
